/**
 * Alpha Color Picker CSS
 */

.customize-control-alpha-color .wp-picker-container .iris-picker {
	border-bottom: none;
}

.customize-control-alpha-color .wp-picker-container {
	max-width: 257px;
}

.customize-control-alpha-color .wp-picker-open + .wp-picker-input-wrap {
	width: 100%;
}

.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
	float: left;
	width: 195px;
}

.customize-control-alpha-color .wp-picker-input-wrap .button {
	margin-left: 0;
	float: right;
}

.wp-picker-container .wp-picker-open ~ .wp-picker-holder .alpha-color-picker-container {
	display: block;
}

.alpha-color-picker-container {
	border: 1px solid #dfdfdf;
	border-top: none;
	display: none;
	background: #FFF;
	padding: 0 11px 10px;
	position: relative;
}

.alpha-color-picker-container .ui-widget-content,
.alpha-color-picker-container .ui-widget-header,
.alpha-color-picker-wrap .ui-state-focus {
	background: transparent;
	border: none;
}

.alpha-color-picker-wrap a.iris-square-value:focus {
	-webkit-box-shadow: none;
	box-shadow: none;
}

.alpha-color-picker-container .ui-slider {
	position: relative;
	z-index: 1;
	height: 24px;
	text-align: center;
	margin: 0 auto;
	width: 88%;
	width: calc( 100% - 28px );
}

.alpha-color-picker-container .ui-slider-handle,
.alpha-color-picker-container .ui-widget-content .ui-state-default {
	color: #777;
	background-color: #FFF;
	text-shadow: 0 1px 0 #FFF;
	text-decoration: none;
	position: absolute;
	z-index: 2;
	box-shadow: 0 1px 2px rgba(0,0,0,0.2);
	border: 1px solid #aaa;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
	margin-top: -2px;
	top: 0;
	height: 26px;
	width: 26px;
	cursor: ew-resize;
	font-size: 0;
	padding: 0;
	line-height: 27px;
	margin-left: -14px;
}

.alpha-color-picker-container .ui-slider-handle.show-opacity {
	font-size: 12px;
}

.alpha-color-picker-container .click-zone {
	width: 14px;
	height: 24px;
	display: block;
	position: absolute;
	left: 10px;
}

.alpha-color-picker-container .max-click-zone {
	right: 10px;
	left: auto;
}

.alpha-color-picker-container .transparency {
	height: 24px;
	width: 100%;
	background-color: #FFF;
	background-image: url(data:image/png;base64,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);
	box-shadow: 0 0 5px rgba(0,0,0,0.4) inset;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	padding: 0;
	margin-top: -24px;
}

@media only screen and (max-width: 782px) {
	.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
		width: 184px;
	}
}

@media only screen and (max-width: 640px) {
	.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
		width: 172px;
		height: 33px;
	}
}
/*EDIT CONTENT CONTROL*/
.edit-content-button{ display:flex !important; align-items: center; gap: 5px; }

/*--------------------------WIDGETS------------------------------------*/
#wp-editor-widget-container{position:fixed;left:0;right:0;bottom:0;z-index:9999999;background:#f1f1f1;border-top:1px solid #ddd;}



@media screen and (min-width: 800px){
	#wp-editor-widget-container{
		left:300px;
	}
}

@media screen and (min-width: 1667px){
	#wp-editor-widget-container{
		left:18%;
	}
}

#wp-editor-widget-container .close{position:absolute;top:17px;right:7px;width:30px;height:30px;z-index:1000; text-decoration: none; opacity:0.4; text-align: center;}
#wp-editor-widget-container .close{ opacity:0.7;}
#wp-editor-widget-container .icon:after{font: 400 22px/45px dashicons; content: "\f335";color: #888;text-decoration: none!important; line-height: 30px}
#wp-editor-widget-container .close:active{outline:0}
#wp-editor-widget-container .editor{margin:50px}
#available-widgets [class*=wp_editor_widget] .widget-title:before{content:"\f478"}

body.wp-customizer #wp-editor-widget-container{ bottom:-650px;}
body.wp-customizer #wp-editor-widget-container.editoron{ bottom:0;}
body.wp-customizer #wp-editor-widget-container .editor {margin: 10px; margin-top: 55px;}
body.widgets_access .widget-position table tr:nth-child(3) {display: none;}
#customize-theme-controls #sub-accordion-section-hestia_typography.customize-pane-child.open {
	height: 100%;
}
.hestia-ss-wrap {
    position: relative;
    box-sizing: border-box;
    border: 1px solid #ddd;
}
.hestia-ss-wrap.active {
    box-shadow: 0 0 2px rgba(30, 140, 190, .8);
    border: 1px solid #5897fb;
}
.customize-control input.hestia-fs-main-input {
	width: 90%;
	background: #fff;
	display: block;
	float: left;
	box-shadow: none;
	cursor: pointer;
    box-sizing: border-box;
    border: 1px solid #ddd;
    border-right: 0;
    border-radius: 0;
    height: 35px;
}
.customize-control input.hestia-fs-main-input:focus {
    border-color: #ddd;
}

.hestia-fs-input-addon {
	width: 10%;
	background: #fff;
	box-sizing: border-box;
	padding: 7px 0;
	line-height: 18px;
	display: inline-block;
	border: 1px solid #ddd;
	text-align: center;
	border-left: 0;
    height: 35px;
}

.hestia-fs-options-wrapper {
	max-height: 300px;
	overflow-y: scroll;
}

.hestia-fs-options-group {
	display: block;
}

.hestia-fs-search {
	padding: 7px;
	display: block;
	border-bottom: 1px solid #ddd;
}

.hestia-fs-option, .hestia-fs-options-heading {
	display: block;
	padding: 3px 5px;
	line-height: 18px;
}

.hestia-fs-option {
	cursor: pointer;
}

.hestia-fs-options-heading {
	font-weight: 600;
	color: #777;
	background: #eee;
}

.hestia-fs-option:hover {
	background: #5897fb;
	color: #fff;
}


.hestia-ss-wrap.active .hestia-fs-dropdown {
	display: block;
	width: 100%;
    z-index: 1000;
}

.hestia-fs-dropdown {
	background: #fff;
	border: 1px solid #ddd;
	border-top: 0;
	display: none;
	position: absolute;
}
.range-slider {
    width: 100%;
    display: flex;
    flex-wrap: wrap;
    align-items: center;
}

.range-slider .control-wrap {
    display: none;
    align-items: center;
    gap: 5px;
}

.range-slider .control-wrap.active {
    display: flex;
}

.range-slider__range {
    background-color: rgba(0, 0, 0, .1);
    height: 5px;
    flex-grow: 1;
    padding: 0;
    cursor: pointer;
    outline: none;
    -webkit-transition: background .5s;
    -moz-transition: background .5s;
    transition: background .5s;
    -webkit-appearance: none;
}

.range-slider__range::-webkit-slider-thumb {
    -webkit-appearance: none;
    width: 15px;
    height: 15px;
    border: none;
    border-radius: 15px;
    background-color: #2e86b9;
}

.range-slider__range::-webkit-slider-thumb:hover {
    background: #0085ba;
}

.range-slider__range:active::-webkit-slider-thumb {
    background: #0085ba;
}

.range-slider__range::-moz-range-thumb {
    width: 20px;
    height: 20px;
    border: 0;
    border-radius: 50%;
    background: #0085ba;
    cursor: pointer;
    -webkit-transition: background .15s ease-in-out;
    transition: background .15s ease-in-out;
}

.range-slider__range::-moz-range-thumb:hover {
    background: #0085ba;
}

.range-slider__range:active::-moz-range-thumb {
    background: #0085ba;
}

.customize-control input[type=number].range-slider-value,
.customize-control input[type=text].range-slider-value {
    height: 28px;
    width: 30%;
    border: 1px solid #a4afb7;
    text-align: center;
    margin-left: 2%;
    border-radius: 3px;
    padding: 3px;
    font-size: 12px;
    font-weight: 600;
    color: #555;
    -moz-appearance: textfield;
}

.customize-control input[type=number].range-slider-value::-webkit-outer-spin-button,
.customize-control input[type=number].range-slider-value::-webkit-inner-spin-button {
    -webkit-appearance: none;
    margin: 0;
}

.customize-control input[type=number].range-slider-value {
    -moz-appearance: textfield;
}

.range-reset-slider .dashicons {
    line-height: 1;
}

.customize-control span.range-reset-slider {
    flex-grow: 1;
    width: 30%;
    color: rgba(0, 0, 0, .2);
    cursor: pointer;
    text-align: center;
    transition: all .3s ease;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -o-transition: all .3s ease;
    -ms-transition: all .3s ease;
}

.customize-control span.range-reset-slider:hover {
    color: #fe5252;
}

::-moz-range-track {
    background: #d7dcdf;
    border: 0;
}

input::-moz-focus-inner, input::-moz-focus-outer {
    border: 0;
}

.customize-control-range-value .customize-control-title {
    display: flex;
    align-items: center;
    gap: 10px;
    margin-bottom: 10px;
    border-top: 1px solid #e5e5e5;
    padding-top: 10px;
}

.responsive-switchers {
    gap: 5px;
}

.responsive-switchers:not(.responsive-switchers-open) .preview-tablet,
.responsive-switchers:not(.responsive-switchers-open) .preview-mobile {
    display: none;
}

.customize-control .responsive-switchers {
    display: flex;
}

.customize-control .responsive-switchers li {
    margin: 0;
}

.customize-control .responsive-switchers li button {
    display: flex;
    align-items: center;
    justify-content: center;
    height: 20px;
    width: 20px;
    background-color: #a4afb7;
    cursor: pointer;
    color: #fff;
    font-size: 10px;
    text-align: center;
    border-radius: 50%;
    padding: 0;
    border: 0;
    outline: none;
    transition: background-color .2s;
}

.customize-control .responsive-switchers li button:hover {
    background-color: #c2cbd2;
}

.customize-control .responsive-switchers li button.active {
    background-color: #13aff0;
}

.customize-control .responsive-switchers li button i {
    width: auto;
    height: auto;
    font-size: inherit;
    line-height: 18px;
}
.iconpicker *,
.icp-container {
    position: relative
}

.icp-container .input-group-addon {
    position: absolute;
    top: 1px;
    left: 5px;
    padding: 3px
}

input.icp {
    padding-left: 30px
}

.iconpicker-popover{
    display: none;
    border: 1px solid;
    padding-bottom: 10px;
}

.iconpicker-popover .popover-title{
    padding: 10px;
    background: #eeeeee;
}

.iconpicker-popover.iconpicker-visible{
    display: block;
}

.iconpicker .iconpicker-items  {
    display: block;
    margin-top: 10px;
    max-height: 200px;
    overflow-y: scroll;
}

.iconpicker .iconpicker-items i {
    display: inline-block;
    width: 32px;
    height: 32px;
    line-height: 32px;
    margin: 3px;
    text-align: center;
    cursor: pointer;
    border-radius: 3px;
    font-size: 18px;
    color: #444;
    box-shadow: 0 0 0 1px #ddd;
    transition: transform .2s ease
}
.customizer-repeater-general-control-repeater-container .customizer-repeater-box-content-hidden:after {
	content: "";
	display: table;
	clear: both;
}

.customizer-repeater-general-control-repeater-container .customizer-repeater-box-content-hidden {
	display: none;
}

.customizer-repeater-customize-control-title {
	margin: 0;
	padding: 15px;
	font-size: 1em;
	line-height: 1;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
	display: block;
	font-weight: 600;
	color: #23282d;
	border: 1px solid #e5e5e5;
	cursor: move;
}

.customizer-repeater-customize-control-title:hover {
	border: 1px solid #999;
}

.customizer-repeater-customize-control-title:after {
	content: "\f140";
	font-family: dashicons;
	font-size: 20px;
	height: 13px;
	bottom: 3px;
	position: relative;
	float: right;
}

.customizer-repeater-customize-control-title.repeater-expanded:after {
	content: "\f142";
}

.customizer-repeater-box-content-hidden {
	border: 1px solid #e5e5e5;
	border-top: none;
	padding: 1px 10px 10px;
}

.customizer-repeater-box-content-hidden > div {
	margin: 1em 0;
}

.customizer-repeater-box-content-hidden .customize-control-title {
	font-size: 13px;
	line-height: 1.5;
	font-weight: normal;
	margin-bottom: 0;
	margin-top: 1em;
}

.customizer-repeater-box-content-hidden .customize-control-title:after {
	content: ":";
}

.customizer-repeater-box-content-hidden span.description {
	font-size: 12px;
	font-style: normal;
}

.customizer-repeater-general-control-repeater-container, .customizer-repeater-general-control-repeater_container {
	border: 1px solid #e5e5e5;
	border-top: none;
	margin-bottom: 12px;
	width: 100%;
	float: left;
	background: #fff;
	-webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, .04);
	box-shadow: 0 1px 1px rgba(0, 0, 0, .04);
}

.customizer-repeater-box-content-hidden .wp-picker-container, .customizer-repeater-box-content-hidden .wp-picker-container .wp-color-result, .icp-container {
	margin: 0;
}

.customizer-repeater-box-content-hidden input:not(.icp, .wp-color-picker),
.customizer-repeater-box-content-hidden textarea,
.customizer-repeater-box-content-hidden .wp-picker-container {
	margin-bottom: 1em !important;
}

.social-repeater-general-control-remove-field {
	cursor: pointer;
	color: #a00;
	background: none;
	border: none;
	padding: 0;
	margin-top: 10px;
}

.social-repeater-general-control-remove-field:hover {
	color: red;
}

.customizer-repeater-box-content-hidden .wp-picker-holder {
	position: relative;
	left: -10px;
}

.customizer-repeater-box-content-hidden .wp-picker-input-wrap {
	margin-left: 10px;
}

.customizer-repeater-box-content-hidden .wp-picker-container .iris-picker {
	border-left: none;
	border-right: none;
}

button.customizer-repeater-new-field {
	float: right;
}

button.customizer-repeater-new-field:before {
	content: "\f132";
	display: inline-block;
	position: relative;
	left: -2px;
	top: -1px;
	font: 400 20px/1 dashicons;
	vertical-align: middle;
	-webkit-transition: all .2s;
	transition: all .2s;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.customizer-repeater-box-content-hidden > div.customizer-repeater-social-repeater {
	margin-top: 0;
}

.customizer-repeater-general-control-repeater-container .customizer-repeater-icon-control {
	width: 100%;
	margin: 0;
	padding: 0;
}

#customizer-repeater-new-field {
	width: 100%;
}

.customize-control-widget_form .widget-control-save {
	display: block !important;
}

.customizer-repeater-box-content-hidden {
	background-color: #fff;
}

.customizer-repeater-image-control .customizer-repeater-custom-media-button {
	margin-top: 5px;
}

.customizer-icons {
	display: inline-block;
	padding: 0 10px 0 0;
	vertical-align: middle;
}

.social-repeater-remove-social-item {
	display: inline-block;
	vertical-align: top;
	color: #a00;
	border: none;
	background: none;
	cursor: pointer;
	padding: 0;
}

.social-repeater-remove-social-item:hover {
	color: red;
}

.customizer-repeater-social-repeater > .customizer-repeater-social-repeater-container:not(:first-child) {
	margin-top: 25px;
}

.icp-container {
	margin-bottom: 10px;
}

.button-secondary.social-repeater-add-social-item:before {
	content: "\f132";
	display: inline-block;
	position: relative;
	left: -2px;
	top: -1px;
	font: 400 20px/1 dashicons;
	vertical-align: middle;
	-webkit-transition: all .2s;
	transition: all .2s;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.button-secondary.social-repeater-add-social-item {
	vertical-align: text-top;
	float: right;
}

.customizer-repeater-box-content-hidden textarea {
	width: 100%;
}
.control-section-hiding-section .hestia-toggle-section,
.control-section-sidebar .hestia-toggle-section{
	text-decoration: none;
	margin-right: 5px;
	vertical-align: middle;
}

.control-section-hiding-section .hestia-toggle-section .dashicons,
.control-section-sidebar .hestia-toggle-section .dashicons{
	font-size:16px;
	vertical-align: middle;
}

.hestia-section-visible .hestia-toggle-section{
	color: #929292;
}

#customize-theme-controls .accordion-section-title.hestia-section-hidden,
.hestia-section-hidden .hestia-toggle-section{
	color: #dcdcdc;
}

.hestia-toggle-section{
	float:left
}
#customize-control-header_video, #customize-control-external_header_video{
    display: none;
}

/**
 * Tab styling
 */
.customizer-tab:not(.customizer-subtab){
    display: table;
    width: calc(100% + 28px);
    margin: -15px 0 0 -12px;
}
.customizer-tab:not(.customizer-subtab) label{
    border-right: 1px solid #ddd;
    display: inherit;
    width: 50%;
    vertical-align: top;
    max-width: 100%;
    text-transform: capitalize;
    background: #fff;
    padding: 10px 0;
    text-decoration: none;
    font-weight: 600;
    transition: all .3s ease;
    color: #333;
}
.customizer-tab:not(.customizer-subtab) label i{
    color: #333;
    margin-right: 4px;
}
.customizer-tab:not(.customizer-subtab) label.ui-state-active{
    box-shadow: inset 0 -3px 0 0 #0085ba;
    color: #0085ba;
    background-color: #fff;
}

.customizer-tab:not(.customizer-subtab) label:last-child{
    border:none;
}

.pro-feature{
    position: relative;
}

.pro-feature img{
    opacity: 0.5;
}
.customize-control-interface-tabs {
	display: list-item !important;
}

.hestia-tabs-control {
	border-bottom: 1px solid #ddd;
	width: calc(100% + 28px);
	margin: -15px 0 0 -12px;
	table-layout: fixed;
	display: table;
}

.hestia-tabs-control .hestia-customizer-tab {
	border-right: 1px solid #ddd;
	display: table-cell;
	text-align: center;
	width: 100%;
}

.hestia-tabs-control .hestia-customizer-tab:last-child {
	border-right: none;
}

.hestia-tabs-control .hestia-customizer-tab label{
	text-transform: capitalize;
	background: #fff;
	box-shadow: inset 0 0 0 0 #0085ba;
	transition: all .3s ease;
	display: block;
	width: 100%;
	padding: 10px 0;
	text-decoration: none;
	font-weight: 600;
	color: #333;
	display: flex;
    align-items: center;
    font-size: inherit;
    line-height: 1;
    justify-content: center;
}

.hestia-tabs-control .hestia-customizer-tab label i {
	color: #333;
	margin-right: 4px;
}

.hestia-tabs-control .hestia-customizer-tab label:hover {
	color: #0085ba;
	background: #f3f3f5;
}

.hestia-tabs-control .hestia-customizer-tab label:hover i {
	color: #333;
}

.hestia-tabs-control .hestia-customizer-tab.active label{
	box-shadow: inset 0 -3px 0 0 #0085ba;
	color: #0085ba;
	background-color: #fff;
}

.hestia-tabs-control input[type="radio"] {
	display: none !important;
}

.hestia-tabs-control span.dashicons-lock {
    font-size: 12px;
    color: #a3a3a3;
    width: 12px;
    height: 12px;
    vertical-align: middle;
}
.hestia-customizer-tab label span:last-child {
    margin-left: 5px;
}

.hestia-customizer-tab label span:first-child {
    margin-right: 3px;
}

#customize-control-hestia_pricing_upsell_notice ~ li {
    opacity: .4;
    pointer-events: none;
}
.customize-control.customize-control-checkbox .dashicons-lock,
.customize-control.customize-control-text .dashicons-lock,
.customize-control.customize-control-media .dashicons-lock,
.customize-control.customize-control-textarea .dashicons-lock,
.customize-control.customize-control-radio-image .dashicons-lock {
	font-size: 16px;
	color: #A3A3A3;
	margin-top: 3px;
}
select + span.dashicons-lock:not(.is-pro-option) {
	opacity: 0;
}
select.is-pro-option + span.dashicons-lock {
	position: absolute;
    bottom: -5px;
    left: 50px;
    font-size: 16px;
    color: #A3A3A3;
    opacity: 1;
}
#customize-control-hestia_slider_type label {
	position: relative;
}
#sub-accordion-section-hestia_big_title:not(.hestia-locked-icon) span.dashicons-lock {
	display: none;
}
#sub-accordion-section-hestia_big_title.hestia-locked-icon li#customize-control-hestia_slider_type ~ li {
	opacity: .4;
    pointer-events: none;
}
#sub-accordion-section-hestia_big_title.hestia-locked-icon #customize-control-hestia_big_title_upsell_notice {
    display: block !important;
}
.customize-locked-control {
    opacity: .4;
    pointer-events: none;
}
#customize-control-hestia_cart_custom_icon:not(.hestia-show-custom-icon) {
	display: none;
}
.customize-control-checkbox#customize-control-hestia_cart_icon_status .dashicons-lock {
	margin-top: 1px;
}
#customize-control-hestia_cart_icon {
	display: none;
}/**
 * Alpha Color Picker CSS
 */

.customize-control-alpha-color .wp-picker-container .iris-picker {
	border-bottom: none;
}

.customize-control-alpha-color .wp-picker-container {
	max-width: 257px;
}

.customize-control-alpha-color .wp-picker-open + .wp-picker-input-wrap {
	width: 100%;
}

.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
	float: left;
	width: 195px;
}

.customize-control-alpha-color .wp-picker-input-wrap .button {
	margin-left: 0;
	float: right;
}

.wp-picker-container .wp-picker-open ~ .wp-picker-holder .alpha-color-picker-container {
	display: block;
}

.alpha-color-picker-container {
	border: 1px solid #dfdfdf;
	border-top: none;
	display: none;
	background: #FFF;
	padding: 0 11px 10px;
	position: relative;
}

.alpha-color-picker-container .ui-widget-content,
.alpha-color-picker-container .ui-widget-header,
.alpha-color-picker-wrap .ui-state-focus {
	background: transparent;
	border: none;
}

.alpha-color-picker-wrap a.iris-square-value:focus {
	-webkit-box-shadow: none;
	box-shadow: none;
}

.alpha-color-picker-container .ui-slider {
	position: relative;
	z-index: 1;
	height: 24px;
	text-align: center;
	margin: 0 auto;
	width: 88%;
	width: calc( 100% - 28px );
}

.alpha-color-picker-container .ui-slider-handle,
.alpha-color-picker-container .ui-widget-content .ui-state-default {
	color: #777;
	background-color: #FFF;
	text-shadow: 0 1px 0 #FFF;
	text-decoration: none;
	position: absolute;
	z-index: 2;
	box-shadow: 0 1px 2px rgba(0,0,0,0.2);
	border: 1px solid #aaa;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
	margin-top: -2px;
	top: 0;
	height: 26px;
	width: 26px;
	cursor: ew-resize;
	font-size: 0;
	padding: 0;
	line-height: 27px;
	margin-left: -14px;
}

.alpha-color-picker-container .ui-slider-handle.show-opacity {
	font-size: 12px;
}

.alpha-color-picker-container .click-zone {
	width: 14px;
	height: 24px;
	display: block;
	position: absolute;
	left: 10px;
}

.alpha-color-picker-container .max-click-zone {
	right: 10px;
	left: auto;
}

.alpha-color-picker-container .transparency {
	height: 24px;
	width: 100%;
	background-color: #FFF;
	background-image: url(data:image/png;base64,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);
	box-shadow: 0 0 5px rgba(0,0,0,0.4) inset;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
	padding: 0;
	margin-top: -24px;
}

@media only screen and (max-width: 782px) {
	.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
		width: 184px;
	}
}

@media only screen and (max-width: 640px) {
	.customize-control-alpha-color .wp-picker-input-wrap input[type="text"].wp-color-picker.alpha-color-control {
		width: 172px;
		height: 33px;
	}
}
/*EDIT CONTENT CONTROL*/
.edit-content-button{ display:flex !important; align-items: center; gap: 5px; }

/*--------------------------WIDGETS------------------------------------*/
#wp-editor-widget-container{position:fixed;left:0;right:0;bottom:0;z-index:9999999;background:#f1f1f1;border-top:1px solid #ddd;}



@media screen and (min-width: 800px){
	#wp-editor-widget-container{
		left:300px;
	}
}

@media screen and (min-width: 1667px){
	#wp-editor-widget-container{
		left:18%;
	}
}

#wp-editor-widget-container .close{position:absolute;top:17px;right:7px;width:30px;height:30px;z-index:1000; text-decoration: none; opacity:0.4; text-align: center;}
#wp-editor-widget-container .close{ opacity:0.7;}
#wp-editor-widget-container .icon:after{font: 400 22px/45px dashicons; content: "\f335";color: #888;text-decoration: none!important; line-height: 30px}
#wp-editor-widget-container .close:active{outline:0}
#wp-editor-widget-container .editor{margin:50px}
#available-widgets [class*=wp_editor_widget] .widget-title:before{content:"\f478"}

body.wp-customizer #wp-editor-widget-container{ bottom:-650px;}
body.wp-customizer #wp-editor-widget-container.editoron{ bottom:0;}
body.wp-customizer #wp-editor-widget-container .editor {margin: 10px; margin-top: 55px;}
body.widgets_access .widget-position table tr:nth-child(3) {display: none;}
#customize-theme-controls #sub-accordion-section-hestia_typography.customize-pane-child.open {
	height: 100%;
}
.hestia-ss-wrap {
    position: relative;
    box-sizing: border-box;
    border: 1px solid #ddd;
}
.hestia-ss-wrap.active {
    box-shadow: 0 0 2px rgba(30, 140, 190, .8);
    border: 1px solid #5897fb;
}
.customize-control input.hestia-fs-main-input {
	width: 90%;
	background: #fff;
	display: block;
	float: left;
	box-shadow: none;
	cursor: pointer;
    box-sizing: border-box;
    border: 1px solid #ddd;
    border-right: 0;
    border-radius: 0;
    height: 35px;
}
.customize-control input.hestia-fs-main-input:focus {
    border-color: #ddd;
}

.hestia-fs-input-addon {
	width: 10%;
	background: #fff;
	box-sizing: border-box;
	padding: 7px 0;
	line-height: 18px;
	display: inline-block;
	border: 1px solid #ddd;
	text-align: center;
	border-left: 0;
    height: 35px;
}

.hestia-fs-options-wrapper {
	max-height: 300px;
	overflow-y: scroll;
}

.hestia-fs-options-group {
	display: block;
}

.hestia-fs-search {
	padding: 7px;
	display: block;
	border-bottom: 1px solid #ddd;
}

.hestia-fs-option, .hestia-fs-options-heading {
	display: block;
	padding: 3px 5px;
	line-height: 18px;
}

.hestia-fs-option {
	cursor: pointer;
}

.hestia-fs-options-heading {
	font-weight: 600;
	color: #777;
	background: #eee;
}

.hestia-fs-option:hover {
	background: #5897fb;
	color: #fff;
}


.hestia-ss-wrap.active .hestia-fs-dropdown {
	display: block;
	width: 100%;
    z-index: 1000;
}

.hestia-fs-dropdown {
	background: #fff;
	border: 1px solid #ddd;
	border-top: 0;
	display: none;
	position: absolute;
}
.range-slider {
    width: 100%;
    display: flex;
    flex-wrap: wrap;
    align-items: center;
}

.range-slider .control-wrap {
    display: none;
    align-items: center;
    gap: 5px;
}

.range-slider .control-wrap.active {
    display: flex;
}

.range-slider__range {
    background-color: rgba(0, 0, 0, .1);
    height: 5px;
    flex-grow: 1;
    padding: 0;
    cursor: pointer;
    outline: none;
    -webkit-transition: background .5s;
    -moz-transition: background .5s;
    transition: background .5s;
    -webkit-appearance: none;
}

.range-slider__range::-webkit-slider-thumb {
    -webkit-appearance: none;
    width: 15px;
    height: 15px;
    border: none;
    border-radius: 15px;
    background-color: #2e86b9;
}

.range-slider__range::-webkit-slider-thumb:hover {
    background: #0085ba;
}

.range-slider__range:active::-webkit-slider-thumb {
    background: #0085ba;
}

.range-slider__range::-moz-range-thumb {
    width: 20px;
    height: 20px;
    border: 0;
    border-radius: 50%;
    background: #0085ba;
    cursor: pointer;
    -webkit-transition: background .15s ease-in-out;
    transition: background .15s ease-in-out;
}

.range-slider__range::-moz-range-thumb:hover {
    background: #0085ba;
}

.range-slider__range:active::-moz-range-thumb {
    background: #0085ba;
}

.customize-control input[type=number].range-slider-value,
.customize-control input[type=text].range-slider-value {
    height: 28px;
    width: 30%;
    border: 1px solid #a4afb7;
    text-align: center;
    margin-left: 2%;
    border-radius: 3px;
    padding: 3px;
    font-size: 12px;
    font-weight: 600;
    color: #555;
    -moz-appearance: textfield;
}

.customize-control input[type=number].range-slider-value::-webkit-outer-spin-button,
.customize-control input[type=number].range-slider-value::-webkit-inner-spin-button {
    -webkit-appearance: none;
    margin: 0;
}

.customize-control input[type=number].range-slider-value {
    -moz-appearance: textfield;
}

.range-reset-slider .dashicons {
    line-height: 1;
}

.customize-control span.range-reset-slider {
    flex-grow: 1;
    width: 30%;
    color: rgba(0, 0, 0, .2);
    cursor: pointer;
    text-align: center;
    transition: all .3s ease;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -o-transition: all .3s ease;
    -ms-transition: all .3s ease;
}

.customize-control span.range-reset-slider:hover {
    color: #fe5252;
}

::-moz-range-track {
    background: #d7dcdf;
    border: 0;
}

input::-moz-focus-inner, input::-moz-focus-outer {
    border: 0;
}

.customize-control-range-value .customize-control-title {
    display: flex;
    align-items: center;
    gap: 10px;
    margin-bottom: 10px;
    border-top: 1px solid #e5e5e5;
    padding-top: 10px;
}

.responsive-switchers {
    gap: 5px;
}

.responsive-switchers:not(.responsive-switchers-open) .preview-tablet,
.responsive-switchers:not(.responsive-switchers-open) .preview-mobile {
    display: none;
}

.customize-control .responsive-switchers {
    display: flex;
}

.customize-control .responsive-switchers li {
    margin: 0;
}

.customize-control .responsive-switchers li button {
    display: flex;
    align-items: center;
    justify-content: center;
    height: 20px;
    width: 20px;
    background-color: #a4afb7;
    cursor: pointer;
    color: #fff;
    font-size: 10px;
    text-align: center;
    border-radius: 50%;
    padding: 0;
    border: 0;
    outline: none;
    transition: background-color .2s;
}

.customize-control .responsive-switchers li button:hover {
    background-color: #c2cbd2;
}

.customize-control .responsive-switchers li button.active {
    background-color: #13aff0;
}

.customize-control .responsive-switchers li button i {
    width: auto;
    height: auto;
    font-size: inherit;
    line-height: 18px;
}
.iconpicker *,
.icp-container {
    position: relative
}

.icp-container .input-group-addon {
    position: absolute;
    top: 1px;
    left: 5px;
    padding: 3px
}

input.icp {
    padding-left: 30px
}

.iconpicker-popover{
    display: none;
    border: 1px solid;
    padding-bottom: 10px;
}

.iconpicker-popover .popover-title{
    padding: 10px;
    background: #eeeeee;
}

.iconpicker-popover.iconpicker-visible{
    display: block;
}

.iconpicker .iconpicker-items  {
    display: block;
    margin-top: 10px;
    max-height: 200px;
    overflow-y: scroll;
}

.iconpicker .iconpicker-items i {
    display: inline-block;
    width: 32px;
    height: 32px;
    line-height: 32px;
    margin: 3px;
    text-align: center;
    cursor: pointer;
    border-radius: 3px;
    font-size: 18px;
    color: #444;
    box-shadow: 0 0 0 1px #ddd;
    transition: transform .2s ease
}
.customizer-repeater-general-control-repeater-container .customizer-repeater-box-content-hidden:after {
	content: "";
	display: table;
	clear: both;
}

.customizer-repeater-general-control-repeater-container .customizer-repeater-box-content-hidden {
	display: none;
}

.customizer-repeater-customize-control-title {
	margin: 0;
	padding: 15px;
	font-size: 1em;
	line-height: 1;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
	display: block;
	font-weight: 600;
	color: #23282d;
	border: 1px solid #e5e5e5;
	cursor: move;
}

.customizer-repeater-customize-control-title:hover {
	border: 1px solid #999;
}

.customizer-repeater-customize-control-title:after {
	content: "\f140";
	font-family: dashicons;
	font-size: 20px;
	height: 13px;
	bottom: 3px;
	position: relative;
	float: right;
}

.customizer-repeater-customize-control-title.repeater-expanded:after {
	content: "\f142";
}

.customizer-repeater-box-content-hidden {
	border: 1px solid #e5e5e5;
	border-top: none;
	padding: 1px 10px 10px;
}

.customizer-repeater-box-content-hidden > div {
	margin: 1em 0;
}

.customizer-repeater-box-content-hidden .customize-control-title {
	font-size: 13px;
	line-height: 1.5;
	font-weight: normal;
	margin-bottom: 0;
	margin-top: 1em;
}

.customizer-repeater-box-content-hidden .customize-control-title:after {
	content: ":";
}

.customizer-repeater-box-content-hidden span.description {
	font-size: 12px;
	font-style: normal;
}

.customizer-repeater-general-control-repeater-container, .customizer-repeater-general-control-repeater_container {
	border: 1px solid #e5e5e5;
	border-top: none;
	margin-bottom: 12px;
	width: 100%;
	float: left;
	background: #fff;
	-webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, .04);
	box-shadow: 0 1px 1px rgba(0, 0, 0, .04);
}

.customizer-repeater-box-content-hidden .wp-picker-container, .customizer-repeater-box-content-hidden .wp-picker-container .wp-color-result, .icp-container {
	margin: 0;
}

.customizer-repeater-box-content-hidden input:not(.icp, .wp-color-picker),
.customizer-repeater-box-content-hidden textarea,
.customizer-repeater-box-content-hidden .wp-picker-container {
	margin-bottom: 1em !important;
}

.social-repeater-general-control-remove-field {
	cursor: pointer;
	color: #a00;
	background: none;
	border: none;
	padding: 0;
	margin-top: 10px;
}

.social-repeater-general-control-remove-field:hover {
	color: red;
}

.customizer-repeater-box-content-hidden .wp-picker-holder {
	position: relative;
	left: -10px;
}

.customizer-repeater-box-content-hidden .wp-picker-input-wrap {
	margin-left: 10px;
}

.customizer-repeater-box-content-hidden .wp-picker-container .iris-picker {
	border-left: none;
	border-right: none;
}

button.customizer-repeater-new-field {
	float: right;
}

button.customizer-repeater-new-field:before {
	content: "\f132";
	display: inline-block;
	position: relative;
	left: -2px;
	top: -1px;
	font: 400 20px/1 dashicons;
	vertical-align: middle;
	-webkit-transition: all .2s;
	transition: all .2s;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.customizer-repeater-box-content-hidden > div.customizer-repeater-social-repeater {
	margin-top: 0;
}

.customizer-repeater-general-control-repeater-container .customizer-repeater-icon-control {
	width: 100%;
	margin: 0;
	padding: 0;
}

#customizer-repeater-new-field {
	width: 100%;
}

.customize-control-widget_form .widget-control-save {
	display: block !important;
}

.customizer-repeater-box-content-hidden {
	background-color: #fff;
}

.customizer-repeater-image-control .customizer-repeater-custom-media-button {
	margin-top: 5px;
}

.customizer-icons {
	display: inline-block;
	padding: 0 10px 0 0;
	vertical-align: middle;
}

.social-repeater-remove-social-item {
	display: inline-block;
	vertical-align: top;
	color: #a00;
	border: none;
	background: none;
	cursor: pointer;
	padding: 0;
}

.social-repeater-remove-social-item:hover {
	color: red;
}

.customizer-repeater-social-repeater > .customizer-repeater-social-repeater-container:not(:first-child) {
	margin-top: 25px;
}

.icp-container {
	margin-bottom: 10px;
}

.button-secondary.social-repeater-add-social-item:before {
	content: "\f132";
	display: inline-block;
	position: relative;
	left: -2px;
	top: -1px;
	font: 400 20px/1 dashicons;
	vertical-align: middle;
	-webkit-transition: all .2s;
	transition: all .2s;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}

.button-secondary.social-repeater-add-social-item {
	vertical-align: text-top;
	float: right;
}

.customizer-repeater-box-content-hidden textarea {
	width: 100%;
}
.control-section-hiding-section .hestia-toggle-section,
.control-section-sidebar .hestia-toggle-section{
	text-decoration: none;
	margin-right: 5px;
	vertical-align: middle;
}

.control-section-hiding-section .hestia-toggle-section .dashicons,
.control-section-sidebar .hestia-toggle-section .dashicons{
	font-size:16px;
	vertical-align: middle;
}

.hestia-section-visible .hestia-toggle-section{
	color: #929292;
}

#customize-theme-controls .accordion-section-title.hestia-section-hidden,
.hestia-section-hidden .hestia-toggle-section{
	color: #dcdcdc;
}

.hestia-toggle-section{
	float:left
}
#customize-control-header_video, #customize-control-external_header_video{
    display: none;
}

/**
 * Tab styling
 */
.customizer-tab:not(.customizer-subtab){
    display: table;
    width: calc(100% + 28px);
    margin: -15px 0 0 -12px;
}
.customizer-tab:not(.customizer-subtab) label{
    border-right: 1px solid #ddd;
    display: inherit;
    width: 50%;
    vertical-align: top;
    max-width: 100%;
    text-transform: capitalize;
    background: #fff;
    padding: 10px 0;
    text-decoration: none;
    font-weight: 600;
    transition: all .3s ease;
    color: #333;
}
.customizer-tab:not(.customizer-subtab) label i{
    color: #333;
    margin-right: 4px;
}
.customizer-tab:not(.customizer-subtab) label.ui-state-active{
    box-shadow: inset 0 -3px 0 0 #0085ba;
    color: #0085ba;
    background-color: #fff;
}

.customizer-tab:not(.customizer-subtab) label:last-child{
    border:none;
}

.pro-feature{
    position: relative;
}

.pro-feature img{
    opacity: 0.5;
}
.customize-control-interface-tabs {
	display: list-item !important;
}

.hestia-tabs-control {
	border-bottom: 1px solid #ddd;
	width: calc(100% + 28px);
	margin: -15px 0 0 -12px;
	table-layout: fixed;
	display: table;
}

.hestia-tabs-control .hestia-customizer-tab {
	border-right: 1px solid #ddd;
	display: table-cell;
	text-align: center;
	width: 100%;
}

.hestia-tabs-control .hestia-customizer-tab:last-child {
	border-right: none;
}

.hestia-tabs-control .hestia-customizer-tab label{
	text-transform: capitalize;
	background: #fff;
	box-shadow: inset 0 0 0 0 #0085ba;
	transition: all .3s ease;
	display: block;
	width: 100%;
	padding: 10px 0;
	text-decoration: none;
	font-weight: 600;
	color: #333;
	display: flex;
    align-items: center;
    font-size: inherit;
    line-height: 1;
    justify-content: center;
}

.hestia-tabs-control .hestia-customizer-tab label i {
	color: #333;
	margin-right: 4px;
}

.hestia-tabs-control .hestia-customizer-tab label:hover {
	color: #0085ba;
	background: #f3f3f5;
}

.hestia-tabs-control .hestia-customizer-tab label:hover i {
	color: #333;
}

.hestia-tabs-control .hestia-customizer-tab.active label{
	box-shadow: inset 0 -3px 0 0 #0085ba;
	color: #0085ba;
	background-color: #fff;
}

.hestia-tabs-control input[type="radio"] {
	display: none !important;
}

.hestia-tabs-control span.dashicons-lock {
    font-size: 12px;
    color: #a3a3a3;
    width: 12px;
    height: 12px;
    vertical-align: middle;
}
.hestia-customizer-tab label span:last-child {
    margin-left: 5px;
}

.hestia-customizer-tab label span:first-child {
    margin-right: 3px;
}

#customize-control-hestia_pricing_upsell_notice ~ li {
    opacity: .4;
    pointer-events: none;
}
.customize-control.customize-control-checkbox .dashicons-lock,
.customize-control.customize-control-text .dashicons-lock,
.customize-control.customize-control-media .dashicons-lock,
.customize-control.customize-control-textarea .dashicons-lock,
.customize-control.customize-control-radio-image .dashicons-lock {
	font-size: 16px;
	color: #A3A3A3;
	margin-top: 3px;
}
select + span.dashicons-lock:not(.is-pro-option) {
	opacity: 0;
}
select.is-pro-option + span.dashicons-lock {
	position: absolute;
    bottom: -5px;
    left: 50px;
    font-size: 16px;
    color: #A3A3A3;
    opacity: 1;
}
#customize-control-hestia_slider_type label {
	position: relative;
}
#sub-accordion-section-hestia_big_title:not(.hestia-locked-icon) span.dashicons-lock {
	display: none;
}
#sub-accordion-section-hestia_big_title.hestia-locked-icon li#customize-control-hestia_slider_type ~ li {
	opacity: .4;
    pointer-events: none;
}
#sub-accordion-section-hestia_big_title.hestia-locked-icon #customize-control-hestia_big_title_upsell_notice {
    display: block !important;
}
.customize-locked-control {
    opacity: .4;
    pointer-events: none;
}
#customize-control-hestia_cart_custom_icon:not(.hestia-show-custom-icon) {
	display: none;
}
.customize-control-checkbox#customize-control-hestia_cart_icon_status .dashicons-lock {
	margin-top: 1px;
}
#customize-control-hestia_cart_icon {
	display: none;
}.accordion-section-title .button {
  font-weight: 400;
}

.hestia-notice {
  position: relative;
}

.hestia-customizer-heading {
  display: block;
  margin: 0 -12px;
  padding: 13px 12px;
  background-color: #fff;
  color: #555;
  border: 1px solid #ddd;
  border-left: 0;
  border-right: 0;
  font-size: 11px;
  font-weight: 600;
  letter-spacing: 2px;
  line-height: 1;
  text-transform: uppercase;
}

.themeisle-upsell {
  background: #fff;
  padding: 21px;
  border-radius: 3px;
}

.themeisle-upsell .upsell-pro-label {
  font-weight: bold;
  background: #a7a7a7;
  color: #fff;
  text-transform: uppercase;
  padding: 2px 6px 2px 7px;
  letter-spacing: 0.1px;
  font-size: 12px;
  border-radius: 3px;
  margin-right: 10px;
}

.themeisle-upsell-features li {
  line-height: 24px;
  margin-bottom: 23px;
  font-size: 14px;
}
.themeisle-upsell-features li:last-child {
  margin-bottom: 20px;
}
.themeisle-upsell-features.no-explained li {
  margin-bottom: 0;
}
.themeisle-upsell-features.no-explained li:last-child {
  margin-bottom: 0;
}

.themeisle-upsell .button {
  margin-right: 21px;
  width: 100%;
  text-align: center;
  letter-spacing: 0.2px;
}

.themeisle-upsell hr {
  margin-top: 22px;
  margin-bottom: 16px;
}

.themeisle-upsell-feature-list li:before {
  line-height: 37px;
}

.themeisle-upsell-feature-list li {
  line-height: 22px;
  font-size: 14px;
  font-style: italic;
  margin-bottom: 6px;
}

.themeisle-upsell-feature-list li:last-child {
  margin-bottom: 0;
}

.frontpage-sections-upsell {
  padding: 10px 10px 11px 14px;
}

.themeisle-boxed-section {
  margin: 12px;
}

.alpha-color-locked {
  margin-top: 3px;
  color: #A3A3A3;
}

.pro-alpha-color {
  opacity: 0.4;
}

.pro-alpha-color button.button {
  pointer-events: none;
}

#customize-control-color_upsell_notice {
  margin-bottom: 25px;
}

#customize-control-color_upsell_notice .description {
  margin-bottom: 12px;
}

#accordion-section-hestia_upsell_main_section.control-section .accordion-section-title {
  color: #2271b1;
  border-color: currentColor;
  border-top: 1px solid;
  border-left-color: transparent;
  border-left: 0;
  padding-left: 17px;
  z-index: 10;
}
#accordion-section-hestia_upsell_main_section.control-section .accordion-section-title:after {
  color: #2271b1;
}
#accordion-section-hestia_upsell_main_section.control-section .accordion-section-title:hover {
  background-color: #0073aa;
  color: #fff !important;
}
#accordion-section-hestia_upsell_main_section.control-section .accordion-section-title:hover:after {
  color: #fff;
}

@media (min-width: 992px) and (max-width: 1300px) {
  body.wp-customizer .wp-full-overlay.expanded {
    margin-left: 280px;
  }
  body.wp-customizer .wp-full-overlay-sidebar {
    width: 280px;
  }
  body.wp-customizer .expanded .wp-full-overlay-footer {
    width: 279px;
  }
}
.customize-control-description a.button span.dashicons {
  vertical-align: middle;
  font-size: initial;
  line-height: initial;
  margin-right: 5px;
  width: auto;
  height: auto;
}

.hestia-section-hidden .hestia-toggle-section.hestia-section-locked {
  color: #A3A3A3;
}

.hestia-section-hidden .hestia-toggle-section.hestia-section-locked + a {
  float: right;
  margin-top: 2px;
}

.customize-locked-control {
  opacity: 0.4;
  pointer-events: none;
}

ul:where([id*=hestia_footer_content], [id*=hestia_buttons_style], [id*=hestia_top_bar]) [id*=upsell] {
  opacity: 0.4;
  pointer-events: none;
}
ul:where([id*=hestia_footer_content], [id*=hestia_buttons_style], [id*=hestia_top_bar]) [id*=upsell]:not([id*=hestia_footer][id*=color]) .customize-control-title::after {
  content: "\f160";
  font-family: "dashicons";
  line-height: 0;
  font-size: 16px;
  margin-left: 2px;
  vertical-align: -2px;
  margin-top: 10px;
}
ul:where([id*=hestia_footer_content], [id*=hestia_buttons_style], [id*=hestia_top_bar]) [id*=upsell] :is(.customize-control-content:has(.wp-picker-container), li > .wp-picker-container)::after {
  font-size: 19px;
  vertical-align: -9px;
}

[id*=hestia][id*=_text_upgrade] {
  margin-top: 10px;
}
[id*=hestia][id*=_text_upgrade] span.upgrade-links {
  font-size: 16px;
  display: flex;
  flex-direction: column;
  gap: 20px;
}
[id*=hestia][id*=_text_upgrade] span.upgrade-links a.button {
  width: fit-content;
}
[id*=hestia][id*=_text_upgrade]:not(:last-child) span.upgrade-links::after, [id*=hestia][id*=_text_upgrade]:last-child span.upgrade-links::before {
  content: "";
  display: block;
  border-top: 1px solid #ddd;
  margin-left: -12px;
  width: 98%;
}
[id*=hestia][id*=_text_upgrade]:last-child span.upgrade-links::before {
  margin-top: 10px;
}

#customize-theme-controls .accordion-section-title button.accordion-trigger {
  max-height: fit-content;
}

#accordion-section-hestia_docs_section .accordion-section-title:after {
  content: "";
}

.customize-hide-control {
  display: none !important;
}

.radio-pagination {
  border: 1px solid #ccc;
  font-family: sans-serif;
  display: flex;
  align-items: center;
  justify-content: center;
  flex-wrap: nowrap;
  height: 30px;
  width: 100%;
  box-sizing: border-box;
  -webkit-overflow-scrolling: touch;
}
.radio-pagination input[type=radio] {
  display: none;
}
.radio-pagination label {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
  border-left: 1px solid #ccc;
  background: transparent;
  cursor: pointer;
  font-size: 14px;
  user-select: none;
  transition: background 0.3s, color 0.3s;
  flex: 1 0 auto;
  text-align: center;
  white-space: nowrap;
  box-sizing: border-box;
}
.radio-pagination label:first-of-type {
  border-left: none;
}
.radio-pagination input[type=radio]:checked + label {
  background-color: #4b4e52;
  color: #fff;
}

#customize-theme-controls .hestia-notice .hestia-notice-body {
  background-color: #fff;
  padding: 5px 18px 2px;
}
#customize-theme-controls .hestia-notice .accordion-section-title::after {
  content: "";
}

.customize-control-color:not([id*=upsell_notice]), .customize-control-alpha-color:not([id*=upsell_notice]) {
  width: 100%;
  display: flex;
  margin-bottom: 12px;
  flex-wrap: wrap;
  justify-content: space-between;
}
.customize-control-color:not([id*=upsell_notice]) .customize-control-title, .customize-control-alpha-color:not([id*=upsell_notice]) .customize-control-title {
  display: flex;
  width: 70%;
}

.wp-picker-container .wp-color-result.button {
  padding: 0 0 0 60px;
}
.wp-picker-container .wp-color-result.button span.wp-color-result-text {
  display: none;
}

.customize-control-hestia-dimensions .customize-control-title {
  display: flex;
  gap: 10px;
}
.customize-control-hestia-dimensions .dimensions-wrap ul li {
  margin-bottom: 0px;
  width: 10px;
}

[class*=alpha-color]:has(.alpha-color-locked) {
  opacity: 0.4;
}